Rev 461: Support creating nested tree repos. in file:///data/jelmer/bzr-svn/nestedtrees/

Jelmer Vernooij jelmer at samba.org
Tue Jul 8 04:45:39 BST 2008


At file:///data/jelmer/bzr-svn/nestedtrees/

------------------------------------------------------------
revno: 461
revision-id: jelmer at samba.org-20080708034538-zy8hll1xc48unpgw
parent: jelmer at samba.org-20080708034524-0w9x92xi8zt1mwl6
committer: Jelmer Vernooij <jelmer at samba.org>
branch nick: nestedtrees
timestamp: Tue 2008-07-08 05:45:38 +0200
message:
  Support creating nested tree repos.
modified:
  format.py                      format.py-20070917005147-94kb7zysotf82kqw-1
=== modified file 'format.py'
--- a/format.py	2008-06-30 13:38:04 +0000
+++ b/format.py	2008-07-08 03:45:38 +0000
@@ -34,12 +34,23 @@
     if format.repository_format.rich_root_data:
         return format
     # Default format does not support rich root data, 
     # fall back to rich-root
     format = format_registry.make_bzrdir('rich-root-pack')
     assert format.repository_format.rich_root_data
     return format
 
 
+def get_nested_tree_format():
+    format = BzrDirFormat.get_default_format()
+    if format.repository_format.supports_tree_reference:
+        return format
+    # Default format does not support rich root data, 
+    # fall back to pack-0.92-subtree
+    format = format_registry.make_bzrdir('pack-0.92-subtree')
+    assert format.repository_format.supports_tree_reference
+    return format
+
+
 class SvnRemoteFormat(BzrDirFormat):
     """Format for the Subversion smart server."""
     _lock_class = TransportLock
@@ -34,12 +34,23 @@
         return format
     # Default format does not support rich root data, 
-    # fall back to rich-root
+    # fall back to rich-root-pack
     format = format_registry.make_bzrdir('rich-root-pack')
     assert format.repository_format.rich_root_data




More information about the bazaar-commits mailing list